@@ -16,7 +16,7 @@ use cursive::traits::Identifiable;
 use librespot_core::authentication::Credentials;
 use librespot_core::cache::Cache;
 use librespot_playback::audio_backend;
-use log::{info, trace};
+use log::{error, info, trace};
 
 mod album;
 mod artist;
@@ -186,15 +186,16 @@ async fn main() -> Result<(), String> {
 
     let queue = Arc::new(queue::Queue::new(spotify.clone(), cfg.clone()));
 
+    let library = Arc::new(Library::new(&event_manager, spotify.clone(), cfg.clone()));
+
     #[cfg(feature = "mpris")]
     let mpris_manager = Arc::new(mpris::MprisManager::new(
         event_manager.clone(),
         spotify.clone(),
         queue.clone(),
+        library.clone(),
     ));
 
-    let library = Arc::new(Library::new(&event_manager, spotify.clone(), cfg.clone()));
-
     let mut cmd_manager = CommandManager::new(
         spotify.clone(),
         queue.clone(),
@@ -229,7 +230,17 @@ async fn main() -> Result<(), String> {
     layout.add_screen("cover", coverview.with_name("cover"));
 
     // initial screen is library
-    layout.set_screen("library");
+    let initial_screen = cfg
+        .values()
+        .initial_screen
+        .clone()
+        .unwrap_or("library".to_string());
+    if layout.has_screen(&initial_screen) {
+        layout.set_screen(initial_screen);
+    } else {
+        error!("Invalid screen name: {}", initial_screen);
+        layout.set_screen("library");
+    }
 
     let cmd_key = |cfg: Arc<Config>| cfg.values().command_key.unwrap_or(':');
 
@@ -288,13 +299,15 @@ async fn main() -> Result<(), String> {
                 }
             } else {
                 let parsed = command::parse(cmd_without_prefix);
-                if let Some(parsed) = parsed {
+                if let Some(commands) = parsed {
                     if let Some(data) = s.user_data::<UserData>().cloned() {
-                        data.cmd.handle(s, parsed)
+                        for cmd in commands {
+                            data.cmd.handle(s, cmd);
+                        }
                     }
                 } else {
                     let mut main = s.find_name::<ui::layout::Layout>("main").unwrap();
-                    let err_msg = format!("Unknown command: \"{}\"", cmd_without_prefix);
+                    let err_msg = format!("Failed to parse command(s): \"{}\"", cmd_without_prefix);
                     main.set_result(Err(err_msg));
                 }
             }
